=======
History
=======

0.1.3 (2020.07.22)
------------------

- 首次发布到 PyPI
- 修复了在动态加载页面中无法获取并下载所有图片的问题
- 保存的图片文件名中加入了序号，以保持原始顺序
- 添加了注释，并对代码细节做了调整

2020.03.25
----------

- 优化了终端输出信息，用不同颜色文字进行了标识
- 修复了在低网速下无法下载图片的问题，并加快了整体下载速度

0.1.2 (2020.03.24)
------------------

新功能：

- 新增下载超清原图（默认选项，约几 MB），使用参数 `--thumbnail` 下载缩略图（宽最大 1280px，约 500KB）
- 新增支持下载 JPG、PNG、GIF、BMP 格式的图片

0.1.1 (2019.12.09)
------------------

新功能：

- 可以选择下载用户的特定主题
- 支持一次性输入多个用户名或 ID

BUG 修复：

- 修复用户如果没有上传任何图片时的下载错误

0.1.0 (2019.09.09)
------------------

主要功能：

- 极速下载：多线程异步下载，可以根据需要设置线程数
- 异常重试：只要重试次数足够多，就没有下载不下来的图片 \(^o^)/
- 增量下载：设计师/用户有新的上传，再跑一遍程序就行了 O(∩_∩)O 嗯！
- 支持代理：可以配置使用代理（0.1.3 版本后改为自动读取系统代理）
